@@ -25,6 +25,12 @@ try:
 except ImportError:
     pass
 
+try:
+    from e2cnn import diffops
+    __all__ += ['diffops']
+except ImportError:
+    pass
+
 try:
     from e2cnn import gspaces
     __all__ += ['gspaces']
