@@ -7,33 +7,31 @@ from typing import List, Union, Tuple
 class EmptyBasisException(Exception):
     def __init__(self):
         r"""
-        Exception raised when a :class:`~e2cnn.kernels.KernelBasis` with no elements is built.
+        Exception raised when a :class:`~e2cnn.kernels.Basis` with no elements is built.
         
         """
-        message = "The KernelBasis you tried to instantiate is empty (dim = 0). You should catch this exception."
+        message = "The Basis you tried to instantiate is empty (dim = 0). You should catch this exception."
         super(EmptyBasisException, self).__init__(message)
-        
 
-class KernelBasis(ABC):
+
+class Basis(ABC):
     
     def __init__(self, dim: int, shape: Tuple[int, int]):
         r"""
         
-        Abstract class for implementing the basis of a kernel space.
-        A kernel space is the space of functions in the form:
+        Abstract class for implementing the basis of a space of maps between
+        feature spaces (either kernels or PDOs).
         
-        .. math::
-            \mathcal{K} := \{ \kappa: X \to \mathbb{R}^{c_\text{out} \times c_\text{in}} \}
-        
-        where :math:`X` is the base space on which the kernel is defined.
-        For instance, for planar images :math:`X = \R^2`.
+        .. seealso ::
+            :class:`e2cnn.kernels.KernelBasis` and
+            :class:`e2cnn.diffops.DiffopBasis`
         
         Args:
-            dim (int): the dimensionality of the basis :math:`|\mathcal{K}|` (number of elements)
+            dim (int): the dimensionality of the basis (number of elements)
             shape (tuple): a tuple containing :math:`c_\text{out}` and :math:`c_\text{in}`
             
         Attributes:
-            ~.dim (int): the dimensionality of the basis :math:`|\mathcal{K}|` (number of elements)
+            ~.dim (int): the dimensionality of the basis (number of elements)
             ~.shape (tuple): a tuple containing :math:`c_\text{out}` and :math:`c_\text{in}`
             
         """
@@ -55,6 +53,40 @@ class KernelBasis(ABC):
         for i in range(self.dim):
             yield self[i]
 
+    @abstractmethod
+    def __getitem__(self, idx: int) -> dict:
+        pass
+    
+    @abstractmethod
+    def __hash__(self):
+        pass
+
+
+class KernelBasis(Basis):
+    
+    def __init__(self, dim: int, shape: Tuple[int, int]):
+        r"""
+        
+        Abstract class for implementing the basis of a kernel space.
+        A kernel space is the space of functions in the form:
+        
+        .. math::
+            \mathcal{K} := \{ \kappa: X \to \mathbb{R}^{c_\text{out} \times c_\text{in}} \}
+        
+        where :math:`X` is the base space on which the kernel is defined.
+        For instance, for planar images :math:`X = \R^2`.
+        
+        Args:
+            dim (int): the dimensionality of the basis :math:`|\mathcal{K}|` (number of elements)
+            shape (tuple): a tuple containing :math:`c_\text{out}` and :math:`c_\text{in}`
+            
+        Attributes:
+            ~.dim (int): the dimensionality of the basis :math:`|\mathcal{K}|` (number of elements)
+            ~.shape (tuple): a tuple containing :math:`c_\text{out}` and :math:`c_\text{in}`
+            
+        """
+        super().__init__(dim, shape)
+
     @abstractmethod
     def sample(self, points: np.ndarray, out: np.ndarray = None) -> np.ndarray:
         r"""
@@ -74,13 +106,34 @@ class KernelBasis(ABC):
         """
         pass
 
-    @abstractmethod
-    def __getitem__(self, idx: int) -> dict:
-        pass
-    
-    @abstractmethod
-    def __hash__(self):
-        pass
+    def sample_masked(self, points: np.ndarray, mask: np.ndarray, out: np.ndarray = None) -> np.ndarray:
+        r"""
+        Mask the basis sampled through :meth:`~e2cnn.kernels.KernelBasis.sample` to drop some basis elements using the
+        input ```mask```.
+        
+        ```mask``` must be a ```np.uint8``` array of shape ```(len(self), )```.
+
+        Args:
+            points (~numpy.ndarray): points where to evaluate the basis elements
+            mask (~numpy.ndarray): binary array to mask the basis
+            out (~numpy.ndarray, optional): pre-existing array to use to store the output
+
+        Returns:
+            the sampled basis
+
+        """
+        
+        assert mask.shape == (self.dim, )
+        assert mask.dtype == np.bool
+
+        basis = self.sample(points)
+        
+        if out is not None:
+            out[:] = basis[..., mask, :]
+        else:
+            out = basis[..., mask, :]
+        
+        return out
 
 
 class GaussianRadialProfile(KernelBasis):
